%define major       0
%define libname     %mklibname %{name} %{major}
%define libname_s   %mklibname %{name}server %{major}
%define libname_a   %mklibname %{name}-atmel %{major}
%define libname_t_g %mklibname %{name}-timecode-generator %{major}
%define libquat     %mklibname quat %{major}
%define libgpsnmea  %mklibname gpsnmea %{major}
%define devname     %mklibname %{name} -d

# Some of the tests randomly hang, others attempt to spin up various network
# services that don't work properly in mock
%bcond_with tests

Name:           vrpn
Version:        07.36
Release:        %mkrel 1
Summary:        Virtual-Reality Peripheral Network
Group:          System/Libraries
License:        BSL-1.0 AND LicenseRef-Fedora-Public-Domain AND GPL-3.0-or-later
URL:            https://github.com/vrpn/vrpn
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        vrpn.service

# Fix modbus libraries detection
Patch2:         vrpn-find_modbus.patch
# Fix Python modules installation
Patch3:         vrpn-python_install.patch
# Add soversion to all libraries
Patch4:         vrpn-soversion.patch
# Do not install binaries only used for unit tests
Patch5:         vrpn-dont-install-tests.patch

BuildRequires:  chrpath
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  graphviz
BuildRequires:  perl
BuildRequires:  sed
BuildRequires:  systemd-rpm-macros
BuildRequires:  swig

BuildRequires:  pkgconfig(glut)
BuildRequires:  pkgconfig(hidapi-libusb)
BuildRequires:  pkgconfig(jsoncpp)
BuildRequires:  pkgconfig(dri)

BuildRequires:  pkgconfig(libmodbus)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(python3)
BuildRequires:  i2c-devel
BuildRequires:  gpm-devel
BuildRequires:  wiiuse-devel

%description
The Virtual-Reality Peripheral Network (VRPN) is a set of classes within a
library and a set of servers that are designed to implement a
network-transparent interface between application programs and the set of
physical devices (tracker, etc.) used in a virtual-reality (VR) system.

The idea is to have a PC or other host at each VR station that controls the
peripherals (tracker, button device, haptic device, analog inputs, sound, etc).
VRPN provides connections between the application and all of the devices using
the appropriate class-of-service for each type of device sharing this link. The
application remains unaware of the network topology. Note that it is possible
to use VRPN with devices that are directly connected to the machine that the
application is running on, either using separate control programs or running
all as a single program.

%package -n %{libname}
Summary:        Client library for Virtual Reality Peripheral Network
Group:          System/Libraries

%description -n %{libname}
The Virtual-Reality Peripheral Network (VRPN) is a set of classes within a
library and a set of servers that are designed to implement a
network-transparent interface between application programs and the set of
physical devices (tracker, etc.) used in a virtual-reality (VR) system.

%package -n %{libname_s}
Summary:        Server library for Virtual Reality Peripheral Network
Group:          System/Libraries

%description -n %{libname_s}
The package contains the shared server library for the
Virtual Reality Peripheral Network.

%package -n %{libname_a}
Summary:        Atmel library for Virtual Reality Peripheral Network
Group:          System/Libraries

%description -n %{libname_a}
The package contains the shared server atmel library for the
Virtual Reality Peripheral Network.

%package -n %{libname_t_g}
Summary:        Timecode generation library for Virtual Reality Peripheral Network
Group:          System/Libraries

%description -n %{libname_t_g}
The package contains the shared server timecode generation library for the
Virtual Reality Peripheral Network.

%package -n %{libquat}
Summary:        Library for quaternion, vector and matrix routines
Group:          System/Libraries

%description -n %{libquat}
quatlib is a library of routines that implements a grab-bag of
useful routines for dealing with quaternions, vectors, and matrices.

%package -n %{libgpsnmea}
Summary:        Library for parsing NMEA streams
Group:          System/Libraries

%description -n %{libgpsnmea}
gpsnmea is a library for parsing NMEA streams.

%package -n %{devname}
Summary:        Development files for the Virtual-Reality Peripheral Network
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libname_s} = %{version}-%{release}
Requires:       %{libname_a} = %{version}-%{release}
Requires:       %{libname_t_g} = %{version}-%{release}
Requires:       %{libquat} = %{version}-%{release}
Requires:       %{libgpsnmea} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
This package contains development files for the VRPN libraries.

%package doc
Summary:        Developer's documentation for VRPN
Group:          Documentation
BuildArch:      noarch

%description doc
This package contains generated VRPN source code documentation.

%package -n python3-%{name}
Summary:        Python 3 bindings for the Virtual-Reality Peripheral Network
Group:          Development/Python

%description -n python3-%{name}
This package contains Python 3 bindings for the VRPN libraries.

%prep
%autosetup -p1

# Fix binaries path
sed -i 's:/usr/local/bin:%{_bindir}:g' vrpn_Connection.C

%build
%cmake \
    -DOpenGL_GL_PREFERENCE=GLVND \
    -DVRPN_GPL_SERVER=ON \
    -DBUILD_TESTING=ON \
    -DVRPN_BUILD_PYTHON_HANDCODED_3X=ON \
    -DVRPN_PYTHON_INSTALL_DIR=%{python3_sitearch} \
    %{nil}
%cmake_build
%cmake_build --target doc

%install
%cmake_install

# Install Python module and strip broken rpath
chrpath -d %{_vpath_builddir}/python/vrpn.so
install -Dpm0755 -t %{buildroot}%{python3_sitearch} %{_vpath_builddir}/python/vrpn.so

# Install systemd service
install -Dpm644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service

# Move sample config out of the way
mv %{buildroot}%{_datadir}/%{name}-%{version}/%{name}.cfg.sample .

%if %{with tests}
%check
%ctest
%endif

%post
%_post_service %{name}

%preun
%_preun_service %{name}

%files
%doc ChangeLog %{name}.cfg.sample
%license README.Legal
%{_bindir}/%{name}*
%{_bindir}/run_auxiliary_logger
%config(noreplace) %{_sysconfdir}/%{name}.cfg
%{_unitdir}/%{name}.service

%files -n %{libname}
%license README.Legal
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n %{libname_s}
%license README.Legal
%{_libdir}/lib%{name}server.so.%{major}{,.*}

%files -n %{libname_a}
%license README.Legal
%{_libdir}/lib%{name}_atmel.so.%{major}{,.*}

%files -n %{libname_t_g}
%license README.Legal
%{_libdir}/lib%{name}_timecode_generator.so.%{major}{,.*}

%files -n %{libquat}
%license README.Legal
%{_libdir}/libquat.so.%{major}{,.*}

%files -n %{libgpsnmea}
%license README.Legal
%{_libdir}/libgpsnmea.so.%{major}{,.*}

%files -n %{devname}
%{_includedir}/latLonCoord.h
%{_includedir}/nmeaParser.h
%{_includedir}/quat.h
%{_includedir}/utmCoord.h
%{_includedir}/%{name}*
%{_libdir}/lib%{name}.so
%{_libdir}/lib%{name}server.so
%{_libdir}/lib%{name}_atmel.so
%{_libdir}/lib%{name}_timecode_generator.so
%{_libdir}/libquat.so
%{_libdir}/libgpsnmea.so

%files doc
%doc Format_Of_Protocol.txt
%doc %{_docdir}/%{name}-%{version}
%exclude %{_docdir}/%{name}-%{version}/source-docs/html/*.map
%exclude %{_docdir}/%{name}-%{version}/source-docs/html/*.md5

%files -n python3-%{name}
%{python3_sitearch}/*.so


%changelog
* Sun Jul 06 2025 daviddavid <daviddavid> 07.36-1.mga10
+ Revision: 2247254
- new version: 07.36

* Mon May 05 2025 daviddavid <daviddavid> 07.35-3.mga10
+ Revision: 2181018
- rebuild for new jsoncpp 1.9.6

* Sun Mar 09 2025 daviddavid <daviddavid> 07.35-2.mga10
+ Revision: 2162190
- backport upstream patch to add support for python 3.13
+ wally <wally>
- rebuild for python3.13

* Sun Feb 11 2024 daviddavid <daviddavid> 07.35-1.mga10
+ Revision: 2040433
- initial package vrpn

